Examples
========

Cone search
-----------

.. plot:: examples/cone_search.py
    :include-source:

Elliptical cone search
----------------------

.. plot:: examples/elliptic_search.py
    :include-source:

Polygon search
--------------

.. plot:: examples/polygon_search.py
    :include-source:

Notebook examples
-----------------

.. nbgallery::
    ../_collections/notebooks/coordinate_conversion.ipynb
    ../_collections/notebooks/external_neighbours.ipynb
